@@ -16,7 +16,7 @@ use LWP::UserAgent;
 use Params::Validate::Checks ':all';
 use Regexp::Common 'Email::Address';
 
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 {  # Hide
 
@@ -99,7 +99,7 @@ our $VERSION = '0.01'; # VERSION
 
       action   => 'POST',
       path     => 'users',
-      required => [qw( email password username name )],
+      required => [qw( email password name )],
       optional => [qw( skype linkedin twitter projects_limit )],
 
     },
@@ -483,7 +483,7 @@ our $VERSION = '0.01'; # VERSION
     }
 
     my %data;
-    %data = validate_with( \@_, spec => $spec )
+    %data = validate_with( params => \@_, spec => $spec )
       if keys %$spec;
 
     if ( keys %data ) {
@@ -546,8 +546,6 @@ our $VERSION = '0.01'; # VERSION
 
     }
 
-    $DB::single = 1;
-
     my %arg = validate_with( params => \@_, spec => $validate );
 
     $self->$_( $arg{ $_ } ) for keys %arg;
@@ -562,28 +560,32 @@ our $VERSION = '0.01'; # VERSION
 
     my $self = shift;
 
-    my ( $method, $data ) = validate_pos(
-      @_,
+    my @specs = { type => SCALAR, regex => qr/^($valid_methods)$/ };
 
-      { type => SCALAR, regex => qr/^($valid_methods)$/ },
-      { type => HASHREF },
+    push @specs, { type => HASHREF }
+      if @_ > 1;
 
-    );
+    my ( $m, $data ) = validate_pos( @_, @specs );
 
-    croak "no action specified for $method"
-      unless exists $method{ $method }->{ action };
+    croak "no action specified for $m"
+      unless exists $method{ $m }->{ action };
 
-    my $action = $method{ $method }->{ action };
-    my $url = sprintf "%s/%s", $self->base_url, $method{ $method }->{ path };
+    my $method = $method{ $m };
+
+    my $action = $method->{ action };
+    my $url = sprintf "%s/%s", $self->base_url, $method->{ path };
 
     $url =~ s/<$_>/delete $data->{ $_ }/ge for $url =~ /<([^>]*)>/g;
 
+    #    $url .= sprintf '?private_token=%s', $self->private_token
+    #       unless $method->{ path } eq '/session';
+
     my $req = HTTP::Request->new( $action => $url );
 
     $req->content_type( 'application/json' );
 
     $req->header( 'private_token' => $self->private_token )
-      unless $method eq '/session';
+      unless $method->{ path } eq '/session';
 
     $req->content( encode_json $data )
       if keys %$data;
@@ -620,7 +622,7 @@ Net::Gitlab - Talk to a Gitlab installation via its API.
 
 =head1 VERSION
 
-  This document describes v0.01 of Net::Gitlab - released December 21, 2012 as part of Net-Gitlab.
+  This document describes v0.02 of Net::Gitlab - released December 25, 2012 as part of Net-Gitlab.
 
 =head1 METHODS
 
